;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "live-py-mode" "20260101.1741"
  "Live Coding in Python."
  '((emacs "24.3"))
  :url "http://donkirkby.github.io/live-py-plugin/"
  :commit "dab6ce73500602a5230a0115a9531e5729ce88ef"
  :revdesc "dab6ce735006"
  :keywords '("live" "coding"))
